Server Class (pysqueezecenter.player.Server) — PySqueezeCenter v0.93 documentation

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.93 documentation »

# Server Class (pysqueezecenter.player.Server)

The Server class deals with the SqueezeCenter server and provides the main communication functions between the PySqueezeCenter API and the SqueezeCenter’s Telnet server.

class `pysqueezecenter.server.` `Server`(hostname='localhost', port=9090, username='', password='')

  SqueezeCenter Server

  `connect`(update=True)

    Connect

  `get_player`(ref=None)

    Get Player

  `get_player_count`()

    Get Number Of Players

  `get_players`(update=True)

    Get Players

  `get_version`()

    Get Version

  `login`()

    Login

  `request`(command_string, preserve_encoding=False)

    Request

  `telnet_connect`()

    Telnet Connect

### Navigation

- index
- next |
- previous |
- PySqueezeCenter v0.93 documentation »